======================
package_template_build
======================


.. image:: https://img.shields.io/pypi/v/package_template_build.svg
        :target: https://pypi.python.org/pypi/package_template_build

.. image:: https://img.shields.io/travis/somedev/package_template_build.svg
        :target: https://travis-ci.org/somedev/package_template_build

.. image:: https://readthedocs.org/projects/package-template-build/badge/?version=latest
        :target: https://package-template-build.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




<yourpackage> provides x, y, and z for all your planetary needs.


* Free software: BSD license
* Documentation: https://package-template-build.readthedocs.io.
* `PlanetaryPy`_ Affiliate Package.


Features
--------

* TODO

Contributing
------------

Feedback, issues, and contributions are always gratefully welcomed. See the
contributing guide for details on how to help and setup a development
environment.


.. _PlanetaryPy: https://github.com/planetarypy
